Learn R Programming

panstarrs (version 0.2.3)

ps1_mast_resolve: Get the RA and Dec for an object using the MAST name resolver

Description

Get the RA and Dec for an object using the MAST name resolver

Usage

ps1_mast_resolve(name)

Value

list of ra, decl

Arguments

name

Name of object

Examples

Run this code
if (FALSE) {
ps1_mast_resolve('Acrux')
}

Run the code above in your browser using DataLab